@@ -34,7 +34,6 @@
 #define R__HAS_SETRESUID   /**/
 #define R__HAS_MATHMORE   /**/
 #define R__HAS_PTHREAD    /**/
-#define R__HAS_CUDA    /**/
 #define R__HAS_XFT    /**/
 #undef R__HAS_COCOA    /**/
 #define R__HAS_VC    /**/
@@ -42,14 +41,6 @@
 #undef R__HAS_VECCORE    /**/
 #undef R__USE_CXXMODULES   /**/
 #undef R__USE_LIBCXX    /**/
-#define R__HAS_STD_STRING_VIEW   /**/
-#define R__CUDA_HAS_STD_STRING_VIEW   /**/
-#undef R__HAS_STD_EXPERIMENTAL_STRING_VIEW   /**/
-#undef R__HAS_STOD_STRING_VIEW /**/
-#define R__HAS_OP_EQUAL_PLUS_STRING_VIEW /**/
-#define R__HAS_STD_APPLY /**/
-#define R__HAS_STD_INVOKE /**/
-#define R__HAS_STD_INDEX_SEQUENCE /**/
 #define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
 #define R__HAS_ATTRIBUTE_NOINLINE /**/
 #undef R__HAS_HARDWARE_INTERFERENCE_SIZE /**/
@@ -59,9 +50,9 @@
 #define R__HAS_QT5WEB  /**/
 #undef R__HAS_DAVIX  /**/
 #define R__HAS_DATAFRAME /**/
+#define R__HAS_ROOT7 /**/
 #undef R__LESS_INCLUDES /**/
 #define R__HAS_TBB /**/
-#undef R__HAS_ROOFIT_MULTIPROCESS /**/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
@@ -77,7 +68,7 @@
 
 #undef R__HAS_TMVACPU /**/
 #define R__HAS_TMVAGPU /**/
-#define R__HAS_CUDNN /**/
+#undef R__HAS_CUDNN /**/
 #define R__HAS_PYMVA /**/
 #undef R__HAS_RMVA /**/
 
